from .ttastromech import TTAstromech
from .ttastromech_pyaudio import TTAstromechPyAudio

from importlib.metadata import version # type: ignore

__author__ = 'Kevin J. Walchko'
__license__ = 'MIT'
__version__ = version("ttastromech")
